/********************************************************************************
 Author : TAbiog (thomas.abiog@analog.com)

 Date : April 2014

 File name : AD7949.c

 Description : Function definition for AD7292 functions

 Hardware plateform : ADuCM360 	
********************************************************************************/
#include <ADUCM360.h>
#include "AD7091R.h"
#include <stdint.h>
#include <stdio.h>
#include <string.h>
#include "ADuCM360Driver.h"

#include "..\common\DioLib.h"



extern unsigned char InputBuf[];
extern unsigned char OutputBuf[];


extern uint8_t szTemp[64];   // Used to store string before printing to UART
extern uint8_t nLen,Nx,ADx;

extern uint16_t ChConfig[], ChData[];

/** @brief ConvStart(void) Toggles the ConvStart Pin at P1.2 **/

void ConvStart(void)
{
		DioClr (pADI_GP1,CNV);
		DioSet (pADI_GP1,CNV);
}

/** @brief WriteRegister(uint32_t RegData, uint8_t NoOfBytes) Writes the Data contained within the RegData thru SPI

		@param RegData	- User Defined Data (0x0000-0xFFFF)
					 NoOfBytes - Number of Bytes to be Sent or Read (0-8)

**/

uint8_t WriteRegister(uint32_t RegData, uint8_t NoOfBytes)
{
	uint8_t Byte = 0;
	
	for(Byte=0;Byte < NoOfBytes;Byte++)
	{
		*(OutputBuf + Byte) = (RegData>>(((NoOfBytes-1)-Byte)*8));
		*(InputBuf + Byte) = 0x00;
	}
		DioClr (pADI_GP1,CS);
		SpiReadWrite(InputBuf, OutputBuf, NoOfBytes);
		DioSet (pADI_GP1,CS);
		return *InputBuf;
}

/** @brief Wr_Config_AD7091R(uint16_t UConfig) Writes the Data contained within the Uconfig to the Configuration Register

		@param UReg	- User Defined Data (0x00-0xFF)

**/

void Wr_Config_AD7091R(uint16_t UConfig)
{
	uint16_t Config=0;	
	Config=(CON_REG|0x0400|UConfig);
	
	WriteRegister(Config,2);
}

/** @brief Rd_Config_AD7091R(void) Returns a 16 bit Data Contained within the Configuration Register **/

uint16_t Rd_Config_AD7091R(void)
{
	uint16_t Config=0;	
	uint16_t DataConfig=0;
	Config=(CON_REG);
	
	WriteRegister(Config,2);
	WriteRegister(0x0000,2);		//send dummy data for data 
	DataConfig = InputBuf[0];
	DataConfig <<= 8;
	DataConfig |=InputBuf[1];
	return DataConfig;
}

/** @brief Wr_AD7091R(uint16_t UReg,uint16_t UConfig) Writes the Data contained by the UConfig within the specified Register UReg

		@param UReg	- User Defined Register (0x00-0x1B)
					 UConfig - User Defined Data (0x00-0xFF)
			
**/

void Wr_AD7091R(uint16_t UReg,uint16_t UConfig)

{
	uint16_t Config=0;	
	uint16_t DataConfig=0;
	Config=(UReg|0x0400|UConfig);
	
	WriteRegister(Config,2);
	DataConfig = InputBuf[0];
	DataConfig <<= 8;
	DataConfig |=InputBuf[1];
}

/** @brief Rd_AD7091R(uint16_t UReg) Reads the Data contained within the specified Register UReg

		@param UReg	- User Defined Register (0x00-0x1B)
			
**/

uint16_t Rd_AD7091R(uint16_t UReg)

{
	uint16_t Config=0;	
	uint16_t DataConfig=0;
	Config=UReg;
	
	WriteRegister(Config,2);
	WriteRegister(0x0000,2);		//send dummy data for data 
	DataConfig = InputBuf[0];
	DataConfig <<= 8;
	DataConfig |=InputBuf[1];
	return DataConfig;
}

/** @brief SoftwareReset(void) Soft Reset the Slave Device  **/

void SoftwareReset(void)
{
	uint16_t Config=0;	
	Config=(CON_REG|0x0400|SOFT_RESET);
	WriteRegister(Config,2);
}
/** @brief Config_Lmt_All(uint16_t ULow,uint16_t UHi) writes a 16-bit data to All Channel's Low Limit & High Limit Register

		@param ULow	- User Defined Low Limit Value (0x000-0xFFF)
					 UHi 	- User Defined High Limit Value (0x000-0xFFF)
**/
void Config_Lmt_All(uint16_t ULow,uint16_t UHi)
{
uint8_t j, k; 	
uint16_t Config=0;
for(k=0x04;k!=0x1C;k+=0x03)
{	
j=k;
Config=(j<<11|0x0400|ULow);
WriteRegister(Config,2);
j+=0x01;
Delay(5);
Config=(j<<11|0x0400|UHi);	
WriteRegister(Config,2);
}
}

/** @brief Config_Lmt_Ch(uint8_t Uch,uint16_t ULow,uint16_t UHi) Writes a 16-bit data to the Specified Channel's Low Limit & High Limit Register

		@param Uch 	- Channel number (0-7)
					 ULow	- User Defined Low Limit Value (0x000-0xFFF)
					 UHi 	- User Defined High Limit Value (0x000-0xFFF)
**/

void Config_Lmt_Ch(uint8_t Uch,uint16_t ULow,uint16_t UHi)
{
	uint16_t Config=0;
	Config=(((Uch*3)+0x04)<<11|0x0400|ULow);
	WriteRegister(Config,2);
	Delay(10);
	Config=(((Uch*3)+0x05)<<11|0x0400|UHi);
  WriteRegister(Config,2);
}

/** @brief Config_Hys_All(uint16_t UHys) Writes a 16-bit data to the All Channel's Hysteresis Register

		@param UHys	- User Defined Hysteresis Value (0x000-0xFFF)
**/
void Config_Hys_All(uint16_t UHys)
{
uint8_t k; 	
uint16_t Config=0;
for(k=0x06;k!=0x1E;k+=0x03)
{	
Config=(k<<11|0x0400|UHys);
WriteRegister(Config,2);
}
}
/** @brief Config_Hys_Ch(uint8_t Uch,uint16_t UHys) Writes a 16-bit data to the Specified Channel's Hysteresis Register

		@param Uch 	- Channel number (0-7)
					 UHys	- User Defined Hysteresis Value (0x000-0xFFF)
**/
void Config_Hys_Ch(uint8_t Uch,uint16_t UHys)
{
	uint16_t Config=0;
	Config=(((Uch*3)+0x06)<<11|0x0400|UHys);
	WriteRegister(Config,2);
}

/** @brief Single_Read_All_Data() Returns a number of 16-bit data of the Converted Data dependent on the Device**/
uint16_t Single_Read_All_Data(void)
{
	uint8_t k;
  uint16_t Config=0,DataConfig;

for(k=0;k!=ADx;k++)
	{
	ConvStart();
	WriteRegister(Config,2);
	DataConfig = InputBuf[0];
	DataConfig <<= 8;
	DataConfig |=InputBuf[1];
	ChData[k] = DataConfig;	
	}
	return *ChData;
}

/** @brief Wr_Chn_Reg(UCh) Writes a 16-bit data of the Channel register

	  @param  - UCh 
		 CH7_EN						Enable Channel 7
		 CH7_DIS					Disable Channel 7
		 CH6_EN						Enable Channel 6
		 CH6_DIS					Disable Channel 6
		 CH5_EN						Enable Channel 5
		 CH5_DIS					Disable Channel 5
		 CH4_EN						Enable Channel 4
		 CH4_DIS					Disable Channel 4
		 CH3_EN						Enable Channel 3
		 CH3_DIS					Disable Channel 3
		 CH2_EN						Enable Channel 2
		 CH2_DIS					Disable Channel 2
		 CH1_EN						Enable Channel 1
		 CH1_DIS					Disable Channel 1
		 CH0_EN						Enable Channel 0
		 CH0_DIS					Disable Channel 0
		 CH_ALL_EN				Enable All Channel
		 CH_ALL_DIS				Disable All Channel

**/
void Wr_Chn_Reg(uint16_t UCh)
{
	uint16_t Config=0;
	Config=(CHN|0x0400|UCh);
	WriteRegister(Config,2);
}
/** @brief Rd_Chn_Reg() Returns a 16-bit data of the Channel Register**/
uint16_t Rd_Chn_Reg(void)
{
	uint16_t Config=0,DataConfig;
	Config=(CHN|0x0000);
	WriteRegister(Config,2);
	WriteRegister(0x0000,2);		//send dummy data for data 
	DataConfig = InputBuf[0];
	DataConfig <<= 8;
	DataConfig |=InputBuf[1];
	return DataConfig;
}

/** @brief Rd_Chn_Def(Uch) Returns a 3-element, 16-bit array of the specified channel(Uch).
		ChConfig[0]= Low Limit value *inclusive of the 3 zero bits appeneded to the register
		ChConfig[1]= High limit value *inclusive of the 3 one bits appeneded to the register
		ChConfig[2]= Hysterysis value
 	@param Uch  - Channel number (0-7)
	**/

uint16_t Rd_Chn_Def(uint16_t Uch)
{
	uint16_t Config=0,DataConfig;
	uint8_t k;
	
	for(k=0;k!=3;k++)
	{
	Config=(((Uch*0x3)+(0x0004+k))<<11|0x0000);
	WriteRegister(Config,2);
	WriteRegister(0x0000,2);		//send dummy data for data 
	DataConfig = InputBuf[0];
	DataConfig <<= 8;
	DataConfig |=InputBuf[1];
	ChConfig[k]=DataConfig;	
	}
		return *ChConfig;
}

/** @brief Rd_Alt_Reg()  Returns a 16-bit data of the ALERT register**/

uint16_t Rd_Alt_Reg(void)
{
	uint16_t Config=0,DataConfig;
	Config=(ALERT|0x0000);
	WriteRegister(Config,2);
	WriteRegister(0x0000,2);		//send dummy data for data 
	DataConfig = InputBuf[0];
	DataConfig <<= 8;
	DataConfig |=InputBuf[1];
	return DataConfig;
}
