/***********************************************************************************
   @version  V1.0
   @author   TAbiog (cic.asia@analog.com)
   @date     April 2014

All files for ADuCM360/361 provided by ADI, including this file, are
provided  as is without warranty of any kind, either expressed or implied.
The user assumes any and all risk from the use of this code.
It is the responsibility of the person integrating this code into an application
to ensure that the resulting application performs as required and is safe.

*************************************************************************************/

#include <stdio.h>
#include <string.h>
#include "AD7091R.h"
#include <ADuCM360.h>
#include <stdint.h>

#include "ADuCM360Driver.h"

#include "..\common\ClkLib.h"
#include "..\common\IntLib.h"
#include "..\common\DioLib.h"
#include "..\common\WdtLib.h"
#include "..\common\DioLib.h"
#include "..\common\UrtLib.h"
#include "..\common\spilib.h"

uint8_t ucTxBufferEmpty  = 0;       // Used to indicate that the UART Tx buffer is empty
uint8_t szTemp[200] = "";           // Used to store string before printing to UART
uint8_t nLen = 0;
uint8_t i = 0;
uint8_t ucWaitForUart = 0;          // Used by calibration routines to wait for user input
uint16_t RBCon,RBChn,x1,x2,x3;

uint16_t ChConfig[3], ChData[8];

//#define AD7091R_2										// Uncomment if you are using AD7091R_2 as slave device, comment the other 2.
//#define AD7091R_4									// Uncomment if you are using AD7091R_4 as slave device, comment the other 2.
#define AD7091R_8									// Uncomment if you are using AD7091R_8 as slave device, comment the other 2.


#ifdef AD7091R_2
uint16_t 	Data0,Data1,Data[2];
uint8_t ADx=2;
#endif

#ifdef AD7091R_4
uint16_t 	Data0,Data1,Data2,Data3,Data[4];
uint8_t ADx=4;
#endif


#ifdef AD7091R_8
uint16_t 	Data0,Data1,Data2,Data3,Data4,Data5,Data6,Data7,Data[8];
uint8_t ADx=8;
#endif


uint8_t InputBuf[4]={0x00,0x00,0x00, 0x00};
uint8_t OutputBuf[4]={0x00,0x00,0x00, 0x00};

int main(void)
{
ADuCM360Initialize();
	
		NVIC_EnableIRQ(UART_IRQn); //Enable UART interrupt
	
	SoftwareReset();
	Delay(10);
	Wr_Config_AD7091R(CLR_ALRT_RD|ALRT_DRV_CMOS|PDOWN_MODE_1);				  // Configures the AD7091R 
//	Wr_Chn_Reg(CH7_EN|CH6_DIS|CH5_EN|CH4_DIS|CH3_EN|CH2_DIS|CH1_EN|CH0_DIS);  // Enables only all odd channels
//	Wr_Chn_Reg(CH7_EN|CH6_EN|CH5_EN|CH4_EN|CH3_EN|CH2_EN|CH1_EN|CH0_EN);	  // Enables all Channels
	Wr_Chn_Reg(CH_ALL_DIS|CH0_EN);
	Config_Lmt_All(0x001,0x1EE);											    // Configure All Low and Hi Limits 
    Config_Hys_All(0x1CC);														  // Configure All Channel Hysteresis

 	RBChn=Rd_Chn_Reg();																	 // Read Channel Register
	RBCon=Rd_Config_AD7091R();					   							 // Read Configuration Register	
	Rd_Chn_Def(0x0001);																	 // Defines the specified Channel's Limits and Hysteresis 
	sprintf ( (char*)szTemp, "\r\nChannel Register is 0x%X \r\nConfig Register is 0x%X \r\n 0x%X 0x%X 0x%X ",RBChn,RBCon,ChConfig[0],ChConfig[1],ChConfig[2]); 
	nLen = strlen((char*)szTemp);
		SendString();
	

 while(1)
{	

	Single_Read_All_Data();
	sprintf ( (char*)szTemp, "\r\n Ch%d: 0x%X, Ch%d: 0x%X, Ch%d: 0x%X, Ch%d: 0x%X, Ch%d: 0x%X, Ch%d: 0x%X, Ch%d: 0x%X, Ch%d: 0x%X ", (ChData[0]>>13),(ChData[0]&0x1FFF),(ChData[1]>>13),(ChData[1]&0x1FFF),(ChData[2]>>13),(ChData[2]&0x1FFF),(ChData[3]>>13),(ChData[3]&0x1FFF),(ChData[4]>>13),(ChData[4]&0x1FFF),(ChData[5]>>13),(ChData[5]&0x1FFF),(ChData[6]>>13),(ChData[6]&0x1FFF),(ChData[7]>>13),(ChData[7]&0x1FFF));
	nLen = strlen((char*)szTemp);
		SendString();

}
}

void SendString (void)
{
   for ( i = 0 ; i < nLen ; i++ )	// loop to send ADC result
   {
      ucTxBufferEmpty = 0;
      UrtTx(pADI_UART,szTemp[i]);
      while (ucTxBufferEmpty == 0)
      {
			
      }
   }
} 

void UART_Int_Handler ()
{
   volatile unsigned char ucCOMSTA0 = 0;
   volatile unsigned char ucCOMIID0 = 0;

   ucCOMIID0 = UrtIntSta(pADI_UART);   // Read UART Interrupt ID register
   if ((ucCOMIID0 & 0x2) == 0x2)       // Transmit buffer empty
   {
      ucTxBufferEmpty = 1;
   }
   if ((ucCOMIID0 & 0x4) == 0x4)       // Receive byte
   {
      ucWaitForUart = 0;
   }
} 
