/********************************************************************************
 Author : TAbiog (cic.asia@analog.com)) 

 Date : April 2014

 File name : ADuCM360Driver.c

 Description : Microcontroller Initilization

 Hardware plateform : ADuCM360	
********************************************************************************/

#include "stdint.h"
#include "ADuCM360.h"
#include "ADuCM360Driver.h"
#include "AD7091R.h"

#include "..\common\ClkLib.h"
#include "..\common\IntLib.h"
#include "..\common\DioLib.h"
#include "..\common\WdtLib.h"
#include "..\common\DioLib.h"
#include "..\common\UrtLib.h"
#include "..\common\spilib.h"

extern unsigned char ucTxComplete;
extern unsigned long ulRxData;


//Delay Routine
void Delay (unint32_t DelayTime)
{
	
	while (DelayTime!= 0)
	{
		DelayTime--;
	}
}

//Initialize UART
void UARTINIT (void)
{
//Select IO pins for UART.
	pADI_GP0->GPCON |= 0x3C;                           // Configure P0.1/P0.2 for UART           
	//pADI_GP0->GPCON |= 0x9000;                      // Configure P0.6/P0.7 for UART
  UrtCfg(pADI_UART,B9600,COMLCR_WLS_8BITS,0);        // setup baud rate for 9600, 8-bits
  UrtMod(pADI_UART,COMMCR_DTR,0);                    // Setup modem bits
  UrtIntCfg(pADI_UART,COMIEN_ERBFI|COMIEN_ETBEI|COMIEN_ELSI|COMIEN_EDSSI|COMIEN_EDMAT|COMIEN_EDMAR);// Setup UART IRQ sources
}

//Initializing SPI interface
void SPIINIT(void)
{
	//Configure Port 1 pins for SPI operation
	DioCfgPin(pADI_GP1,PIN4,2);                           // Configure P1.4 as MISO
	DioCfgPin(pADI_GP1,PIN5,2);                           // Configure P1.5 as SCLK   
	DioCfgPin(pADI_GP1,PIN6,2);                           // Configure P1.6 as MOSI
	DioCfgPin(pADI_GP1,PIN7,2);                           // Configure P1.7 as SS

	//Configure SPI0 for operation 
	//SpiBaud(pADI_SPI0,0x04,SPIDIV_BCRST_EN);              // Configure SPI0 baud rate for 2.6MHz
	SpiBaud(pADI_SPI0,0,SPIDIV_BCRST_EN);										// Configure SPI0 baud rate for 8 MHz
	SpiCfg(pADI_SPI0,SPICON_MOD_TX1RX1,SPICON_MASEN_EN,SPICON_CON_EN|SPICON_RXOF_EN|SPICON_ZEN_EN|SPICON_TIM_TXWR|
					SPICON_CPOL_LOW|SPICON_CPHA_SAMPLELEADING|SPICON_ENABLE_EN);
	SpiFifoFlush(pADI_SPI0,SPICON_TFLUSH_EN,SPICON_RFLUSH_EN);
	
}
//Initialize ADuC360 for AD
void ADuCM360Initialize(void)
{
	WdtCfg(T3CON_PRE_DIV1,T3CON_IRQ_EN,T3CON_PD_DIS);      // Disable Watchdog timer resets
	
	//Disable clock to unused peripherals
	ClkDis(CLKDIS_DISI2CCLK|CLKDIS_DISPWMCLK|CLKDIS_DIST0CLK|CLKDIS_DIST1CLK|CLKDIS_DISDACCLK);  // Disable unused clock
	ClkCfg(CLK_CD0,CLK_HF,CLKSYSDIV_DIV2EN_DIS,CLK_UCLKCG);// Select CD0 for CPU clock - 16Mhz clock
	ClkSel(CLK_CD0,CLK_CD0,CLK_CD0,CLK_CD7);               // Select CD0 for SPI clocks
	
	
	DioCfgPin(pADI_GP1,PIN3,0);                           // Configure P1.3 as SS
	DioCfgPin(pADI_GP1,PIN2,0);														// Config P1.2 as CNV

	
	DioOenPin(pADI_GP1,PIN3,1);			
	DioOenPin(pADI_GP1,PIN2,1);		
	
	DioSet(pADI_GP1, CNV);
	DioSet(pADI_GP1, CS);

	DioCfgPin(pADI_GP0,PIN5,0);                           // Configure P0.5 as GPI for GPO0
	DioCfgPin(pADI_GP0,PIN6,0);						 	  // Configure P0.6 as GPI for GPO1

	
	DioOcePin(pADI_GP0,PIN5,0);							  
	DioOcePin(pADI_GP0,PIN6,0);		

	DioOenPin(pADI_GP0,PIN5,0);			
	DioOenPin(pADI_GP0,PIN6,0);		
	
		
	SPIINIT();
	UARTINIT(); //Initializing UART
}

/**
	@brief void SpiReadWrite(uint8_t *InputBuffer, uint8_t *OutputBuffer, uint8_t NoOfBytes)
	- Read and Write the regsiter
		@param *InputBuffer : Input Buffer
    @param *OutputBuffer : Output Buffer
    @param NoOfBytes : Number of Bytes for Read and Write
		@ - no return value
**/
void SpiReadWrite(uint8_t *InputBuffer, uint8_t *OutputBuffer, uint8_t NoOfBytes)
{
	
	unsigned char Register;
	uint32_t Byte;

	for(Byte=0;Byte<NoOfBytes;Byte++)
	{
		Register = *OutputBuffer;
		SpiTx(pADI_SPI0, Register); //Writing Communication Register and Data
		while((SpiSta(pADI_SPI0) & 0x0700) != 0x0100){} //Waiting till valid data
		*InputBuffer=SpiRx(pADI_SPI0); //Reading data from specified register in communication register
		OutputBuffer++;
		InputBuffer++;
	}
		
}


/**
	@brief void ADuCM360GpioOutput  (unsigned char  GpioNo, unsigned char OutputValue)
	- Configures the GPIO's as output based on pin assigned to the Controllers
		@param GpioNo : Pin number XY, X - Port number, Y - Pin Number
		@ - no return value
**/
void ADuCM360GpioOutput  (unsigned char  GpioNo, unsigned char OutputValue)
{
	unsigned char PortNo  =  GpioNo  & 0xF0; // Extracting the Port number
	unsigned char PinNo  =  GpioNo  & 0x0F;	//Extracting the Pin number
	switch(PortNo)
	{	
		case 0x00:
				if(OutputValue == 0x1)
					pADI_GP0->GPSET =  (1<< PinNo);
				else if(OutputValue == 0x0)
					pADI_GP0->GPCLR =  (1<< PinNo);
				break;
				
		case 0x10:
				if(OutputValue == 0x1)
					pADI_GP1->GPSET =  (1<< PinNo);
				else if(OutputValue == 0x0)
					pADI_GP1->GPCLR =  (1<< PinNo);
				break;
				
		case 0x20: 
				if(OutputValue == 0x1)
					pADI_GP2->GPSET =  (1<< PinNo);
				else if(OutputValue == 0x0)
					pADI_GP2->GPCLR =  (1<< PinNo);
				break;
	}
}
